@@ -1,8 +1,8 @@
 import json
 from typing import List
 
-from botoy.contrib import check_schema
-from botoy.exceptions import InvalidConfigError
+from .exceptions import InvalidConfigError
+from .utils import check_schema
 
 # | host             | ip或域名                           | 127.0.0.1      |
 # | port             | 端口，也可以不需要                 | 8888           |
